using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Grouping;
using System.Collections;

namespace WindowsApplication32
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            #region Get the DataSource
            DataTable dt = new DataTable("MyTable");

            int nCols = 4;
            int nRows = 20;
            Random r = new Random(123345345);

            for (int i = 0; i < nCols; i++)
                dt.Columns.Add(new DataColumn(string.Format("Col{0}", i), typeof(int)));

            for (int i = 0; i < nRows; ++i)
            {
                DataRow dr = dt.NewRow();
                for (int j = 0; j < nCols; j++)
                    dr[j] = r.Next(10);
                dt.Rows.Add(dr);
            }
            #endregion

            this.gridGroupingControl1.DataSource = dt;

            //add an invisible unbound column that will hold a record reference
            FieldDescriptor fd = new FieldDescriptor("unbound", typeof(Record));
            this.gridGroupingControl1.TableDescriptor.UnboundFields.Add(fd);

            //hide it 
            if (this.gridGroupingControl1.TableDescriptor.VisibleColumns.IndexOf("unbound") > -1)
                this.gridGroupingControl1.TableDescriptor.VisibleColumns.Remove("unbound");

            //handle event to provide the unbound values for the column
            this.gridGroupingControl1.QueryValue += new FieldValueEventHandler(gridGroupingControl1_QueryValue);
        }

        void gridGroupingControl1_QueryValue(object sender, FieldValueEventArgs e)
        {
            if (e.Field.Name == "unbound")
            {
                //provide the underlying data object from the record as the value
                e.Value = e.Record.GetData();
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            if (this.gridGroupingControl1.TableDescriptor.SortedColumns.IndexOf("unbound") == -1)
            {
                SortColumnDescriptor scd = new SortColumnDescriptor("unbound");
                scd.Comparer = new CustomComparer();
                this.gridGroupingControl1.TableDescriptor.SortedColumns.Add(scd);
            }
            else
            {
                SortColumnDescriptor scd = this.gridGroupingControl1.TableDescriptor.SortedColumns["unbound"];
                scd.SortDirection = (scd.SortDirection == ListSortDirection.Ascending) ? ListSortDirection.Descending : ListSortDirection.Ascending;
            }
        }
    }

    class CustomComparer : IComparer
    {

        #region IComparer Members

        public int Compare(object x, object y)
        {
            DataRowView rx = x as DataRowView;
            DataRowView ry = y as DataRowView;
            if (rx == null && ry == null)
                return 0;
            else if (rx == null)
                return -1;
            else if (ry == null)
                return 1;
            IComparable vx = rx["Col1"] as IComparable;
            return vx.CompareTo(ry["Col1"]);


        }

        #endregion
    }
}